==> seedsui-react-5.8.2.tgz: package/lib/DatePicker/RangeModal/SelectorModal/CustomButton.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["portal", "captionProps", "submitProps", "cancelProps", "onVisibleChange", "value", "allowClear", "onBeforeChange", "onChange", "defaultPickerValue", "titles", "type", "ranges"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useState } from 'react';
import _ from 'lodash';
import Selector from "./../../../Selector";
import getCustomKey from "./../../RangeMain/getCustomKey";
import getActiveOption from "./../../RangeMain/getActiveOption";
import PickerModal from "./../PickerModal";

// 快捷选择
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var CustomButton = function CustomButton(_ref) {
  var _getActiveOption;
  var portal = _ref.portal,
    captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    onVisibleChange = _ref.onVisibleChange,
    value = _ref.value,
    allowClear = _ref.allowClear,
    onBeforeChange = _ref.onBeforeChange,
    _onChange = _ref.onChange,
    defaultPickerValue = _ref.defaultPickerValue,
    titles = _ref.titles,
    type = _ref.type,
    ranges = _ref.ranges,
    props = _objectWithoutProperties(_ref, _excluded);
  // 获取自定义项的key，不是数组则为自定义项:
  var customKey = getCustomKey(ranges);

  // Picker选择控件
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    pickerVisible = _useState2[0],
    setPickerVisible = _useState2[1];
  if (!customKey) return null;
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [typeof titles.custom === 'string' ? /*#__PURE__*/_jsx("p", {
      className: "datepicker-selector-caption",
      children: titles.custom
    }) : null, /*#__PURE__*/_jsx(Selector, {
      columns: 1,
      allowClear: allowClear,
      value: ((_getActiveOption = getActiveOption(value, ranges)) === null || _getActiveOption === void 0 ? void 0 : _getActiveOption.name) === customKey ? [{
        id: customKey,
        name: customKey
      }] : null,
      list: [{
        id: customKey,
        name: customKey
      }],
      onChange: function onChange(newValue) {
        // 清空
        if (_.isEmpty(newValue)) {
          _onChange && _onChange(null);
          onVisibleChange && onVisibleChange(false);
        }
        // 弹出选择
        else {
          onVisibleChange && onVisibleChange(false);
          setPickerVisible(true);
        }
      }
    }), /*#__PURE__*/_jsx(PickerModal, _objectSpread({
      captionProps: captionProps,
      submitProps: submitProps,
      cancelProps: cancelProps,
      portal: portal,
      value: value,
      defaultPickerValue: defaultPickerValue,
      type: type,
      onBeforeChange: onBeforeChange,
      onChange: _onChange,
      visible: pickerVisible,
      onVisibleChange: setPickerVisible
    }, props))]
  });
};
export default CustomButton;

==> seedsui-react-5.8.3.tgz: package/lib/DatePicker/RangeModal/SelectorModal/CustomButton.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["portal", "captionProps", "submitProps", "cancelProps", "onVisibleChange", "value", "allowClear", "onBeforeChange", "onChange", "defaultPickerValue", "titles", "type", "ranges"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useState } from 'react';
import _ from 'lodash';
import Selector from "./../../../Selector";
import getCustomKey from "./../../RangeMain/getCustomKey";
import getActiveOption from "./../../RangeMain/getActiveOption";
import PickerModal from "./../PickerModal";

// 快捷选择
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var CustomButton = function CustomButton(_ref) {
  var _getActiveOption;
  var portal = _ref.portal,
    captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    onVisibleChange = _ref.onVisibleChange,
    value = _ref.value,
    allowClear = _ref.allowClear,
    onBeforeChange = _ref.onBeforeChange,
    _onChange = _ref.onChange,
    defaultPickerValue = _ref.defaultPickerValue,
    titles = _ref.titles,
    type = _ref.type,
    ranges = _ref.ranges,
    props = _objectWithoutProperties(_ref, _excluded);
  // 获取自定义项的key，不是数组则为自定义项:
  var customKey = getCustomKey(ranges);

  // Picker选择控件
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    pickerVisible = _useState2[0],
    setPickerVisible = _useState2[1];
  if (!customKey) return null;
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [typeof (titles === null || titles === void 0 ? void 0 : titles.custom) === 'string' ? /*#__PURE__*/_jsx("p", {
      className: "datepicker-selector-caption",
      children: titles.custom
    }) : null, /*#__PURE__*/_jsx(Selector, {
      columns: 1,
      allowClear: allowClear,
      value: ((_getActiveOption = getActiveOption(value, ranges)) === null || _getActiveOption === void 0 ? void 0 : _getActiveOption.name) === customKey ? [{
        id: customKey,
        name: customKey
      }] : null,
      list: [{
        id: customKey,
        name: customKey
      }],
      onChange: function onChange(newValue) {
        // 清空
        if (_.isEmpty(newValue)) {
          _onChange && _onChange(null);
          onVisibleChange && onVisibleChange(false);
        }
        // 弹出选择
        else {
          onVisibleChange && onVisibleChange(false);
          setPickerVisible(true);
        }
      }
    }), /*#__PURE__*/_jsx(PickerModal, _objectSpread({
      captionProps: captionProps,
      submitProps: submitProps,
      cancelProps: cancelProps,
      portal: portal,
      value: value,
      defaultPickerValue: defaultPickerValue,
      type: type,
      onBeforeChange: onBeforeChange,
      onChange: _onChange,
      visible: pickerVisible,
      onVisibleChange: setPickerVisible
    }, props))]
  });
};
export default CustomButton;
